agentle.agents.a2a.tasks.task\_status
=====================================

.. automodule:: agentle.agents.a2a.tasks.task_status

   
   .. rubric:: Classes

   .. autosummary::
   
      BaseModel
      Message
      TaskState
      TaskStatus
      datetime
   